@@ -1,20 +1,8 @@
-/*******************************************************************************
-  Copyright 2008 Ian Wadham <iandw.au@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2008 Ian Wadham <iandw.au@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-*******************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own header
 #include "cube.h"
@@ -76,7 +64,7 @@ void Cube::moveSlice (Axis axis, int location, Rotation direction)
     }
 
     // Rotate all cubies that are in the required slice.
-    for (Cubie * cubie : qAsConst(cubies)) {
+    for (Cubie * cubie : std::as_const(cubies)) {
 	cubie->rotate (axis, location, direction);
     }
     setBlinkingOff ();
@@ -93,7 +81,7 @@ void Cube::addStickers ()
 	    int location = sign * sizes [n];
 
 	    color++;				// FaceColor enum 1 --> 6.
-	    for (Cubie * cubie : qAsConst(cubies)) {
+	    for (Cubie * cubie : std::as_const(cubies)) {
 		cubie->addSticker ((FaceColor) color, (Axis) n, location, sign);
 	    }
 	}
@@ -104,7 +92,7 @@ void Cube::addStickers ()
 void Cube::drawCube (GameGLView * gameGLView, float cubieSize)
 {
     // For each cubie in the cube ...
-    for (Cubie * cubie : qAsConst(cubies)) {
+    for (Cubie * cubie : std::as_const(cubies)) {
 
 	if (cubie->hasNoStickers()) {
 	    // This cubie is deep inside the cube: save time by not drawing it.
@@ -124,20 +112,19 @@ bool Cube::findSticker (double position [], float myCubieSize,
     bool             result       = false;
     double           location [nAxes];
     double           distance     = sqrt ((double) 2.0);
-    double	     d;
 
     // Calculate the position in the cube's internal co-ordinate system.
     LOOP (i, nAxes) {
-	location [i] = (position [i] / myCubieSize) * 2.0;
-	// IDW faceCentre [i] = 0;		// Return zeroes if no sticker is found.
+        location [i] = (position [i] / myCubieSize) * 2.0;
+        // IDW faceCentre [i] = 0;		// Return zeroes if no sticker is found.
     }
 
-    for (Cubie * cubie : qAsConst(cubies)) {
-	d = cubie->findCloserSticker (distance, location, faceCentre);
-	if (d < distance) {
-	    distance = d;
-	    result = true;
-	}
+    for (Cubie * cubie : std::as_const(cubies)) {
+        double d = cubie->findCloserSticker (distance, location, faceCentre);
+        if (d < distance) {
+            distance = d;
+            result = true;
+        }
     }
 
     return (result);
@@ -160,7 +147,7 @@ void Cube::setMoveAngle (int angle)
 
 void Cube::setBlinkingOn (Axis axis, int location)
 {
-    for (Cubie * cubie : qAsConst(cubies)) {
+    for (Cubie * cubie : std::as_const(cubies)) {
 	cubie->setBlinkingOn (axis, location, sizes[axis]);
     }
 }
@@ -168,7 +155,7 @@ void Cube::setBlinkingOn (Axis axis, int location)
 
 void Cube::setBlinkingOff ()
 {
-    for (Cubie * cubie : qAsConst(cubies)) {
+    for (Cubie * cubie : std::as_const(cubies)) {
 	cubie->setBlinkingOff ();
     }
 }
@@ -227,7 +214,7 @@ void Cubie::rotate (Axis axis, int location, Rotation direction)
 	    temp   = currentCentre [coord1];
 	    currentCentre [coord1] = - currentCentre [coord2];
 	    currentCentre [coord2] = + temp;
-	    for (Sticker * s : qAsConst(stickers)) {
+	    for (Sticker * s : std::as_const(stickers)) {
 		temp   = s->currentFaceCentre [coord1];
 		s->currentFaceCentre [coord1] = - s->currentFaceCentre [coord2];
 		s->currentFaceCentre [coord2] = + temp;
@@ -237,7 +224,7 @@ void Cubie::rotate (Axis axis, int location, Rotation direction)
 	    temp   = currentCentre [coord1];
 	    currentCentre [coord1] = + currentCentre [coord2];
 	    currentCentre [coord2] = - temp;
-	    for (Sticker * s : qAsConst(stickers)) {
+	    for (Sticker * s : std::as_const(stickers)) {
 		temp   = s->currentFaceCentre [coord1];
 		s->currentFaceCentre [coord1] = + s->currentFaceCentre [coord2];
 		s->currentFaceCentre [coord2] = - temp;
@@ -246,7 +233,7 @@ void Cubie::rotate (Axis axis, int location, Rotation direction)
 	case (ONE_EIGHTY):	// eg. around the Z-axis, X --> -X and Y --> -Y.
 	    currentCentre [coord1] = - currentCentre [coord1];
 	    currentCentre [coord2] = - currentCentre [coord2];
-	    for (Sticker * s : qAsConst(stickers)) {
+	    for (Sticker * s : std::as_const(stickers)) {
 		s->currentFaceCentre [coord1] = - s->currentFaceCentre [coord1];
 		s->currentFaceCentre [coord2] = - s->currentFaceCentre [coord2];
 	    }
@@ -313,7 +300,7 @@ void Cubie::drawCubie (GameGLView * gameGLView, float cubieSize,
     int   faceNormal [nAxes];
 
     // For each sticker on this cubie (there may be 0->3 stickers) ...
-    for (Sticker * sticker : qAsConst(stickers)) {
+    for (Sticker * sticker : std::as_const(stickers)) {
 	// Calculate the integer unit-vector normal to this sticker's face
 	// and the centre of the face, in floating OpenGL co-ordinates.
 	LOOP (j, nAxes) {
@@ -339,9 +326,9 @@ double Cubie::findCloserSticker (double distance, double location [],
 {
     double    len          = 0.0;
     double    dmin         = distance;
-    Sticker * foundSticker = 0;
+    Sticker * foundSticker = nullptr;
 
-    for (Sticker * sticker : qAsConst(stickers)) {
+    for (Sticker * sticker : std::as_const(stickers)) {
 	double d = 0.0;
 	LOOP (n, nAxes) {
 	    len = location[n] - sticker->currentFaceCentre[n];
@@ -354,7 +341,7 @@ double Cubie::findCloserSticker (double distance, double location [],
 	}
     }
 
-    if (foundSticker != 0) {
+    if (foundSticker != nullptr) {
 	LOOP (n, nAxes) {
 	    faceCentre[n] = foundSticker->currentFaceCentre[n];
 	}
@@ -373,7 +360,7 @@ void Cubie::setBlinkingOn (Axis axis, int location, int cubeBoundary)
 
     // If the sticker is on the outside edges of the slice, make it blink, but
     // not if it is perpendicular to the move-axis (ie. on the slice's face).
-    for (Sticker * sticker : qAsConst(stickers)) {
+    for (Sticker * sticker : std::as_const(stickers)) {
 	if (abs(sticker->currentFaceCentre [axis]) != cubeBoundary) {
 	    sticker->blinking = true;
 	}
@@ -383,7 +370,7 @@ void Cubie::setBlinkingOn (Axis axis, int location, int cubeBoundary)
 
 void Cubie::setBlinkingOff ()
 {
-    for (Sticker * sticker : qAsConst(stickers)) {
+    for (Sticker * sticker : std::as_const(stickers)) {
 	sticker->blinking = false;
     }
 }
@@ -399,7 +386,7 @@ void Cubie::printAll ()
 	printf ("<NONE>\n");
     }
     else {
-	for (Sticker * sticker : qAsConst(stickers)) {
+	for (Sticker * sticker : std::as_const(stickers)) {
 	    printf ("<%d> at ", (int) sticker->color);
 	    LOOP (n, nAxes) {
 		printf ("%2d ", sticker->currentFaceCentre [n]);
@@ -422,7 +409,7 @@ void Cubie::printChanges ()
 
     // Check if the cubie is back where it was but has been given a twist.
     if (! moved) {
-	for (Sticker * s : qAsConst(stickers)) {
+	for (Sticker * s : std::as_const(stickers)) {
 	    LOOP (i, nAxes) {
 		if (s->currentFaceCentre [i] != s->originalFaceCentre [i])
 		    moved = true;
